@@ -1,6 +1,6 @@
 package Web::PerlDistSite::Component::MainScss;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
@@ -13,6 +13,9 @@ sub filename ( $self ) {
 
 sub raw_content ( $self ) {
 	state $content = do { local $/ = <DATA> };
+	if ( $self->project->root->child( 'custom.scss' )->is_file ) {
+		return $content . qq{\n\@import "../custom";\n\n}
+	}
 	return $content;
 }
 
@@ -36,6 +39,28 @@ __DATA__
 @import "../node_modules/bootstrap/scss/root";
 @import "../node_modules/bootstrap/scss/utilities";
 
+$sizes: (
+	25: 25%,
+	50: 50%,
+	75: 75%,
+	100: 100%,
+	60px: 60px,
+	80px: 80px,
+	100px: 100px,
+	auto: auto
+);
+
+@each $breakpoint in map-keys($grid-breakpoints) {
+	@include media-breakpoint-up($breakpoint) {
+		$infix: breakpoint-infix($breakpoint, $grid-breakpoints);
+		@each $prop, $abbrev in (width: w, height: h) {
+			@each $size, $length in $sizes {
+				.#{$abbrev}#{$infix}-#{$size} { #{$prop}: $length !important; }
+			}
+		}
+	}
+}
+
 // 6. Optionally include any other parts as needed
 @import "../node_modules/bootstrap/scss/reboot";
 @import "../node_modules/bootstrap/scss/type";
@@ -73,4 +98,4 @@ __DATA__
 @import "../node_modules/bootstrap/scss/utilities/api";
 
 // 8. Add additional custom code here
-@import "custom";
+@import "layout";
