@@ -1,7 +1,7 @@
 package Web::PerlDistSite::MenuItem;
 use utf8;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
@@ -130,7 +130,7 @@ sub _compile_dom ( $self, $dom ) {
 		unshift $pp->{element}{compact}->@*, 'a';
 		$pp;
 	};
-	state $w = HTML::HTML5::Writer->new( markup => 'html', polyglot => true );
+	state $w = HTML::HTML5::Writer->new( markup => 'xhtml', polyglot => true );
 	my $sane = fix_document( $dom );
 	$p->pretty_print( $sane );
 	return $w->document( $sane );
